Experimental 3-bit/5-bit kernels developed during the CUDA MODE IRL Hackathon!

<div class="row"><center>
  <div class="column">
    <img src="https://github.com/mobiusml/gemlite/blob/master/images/W3_W5_experimental.svg" alt="8bit_gs=infeatures_32768x32768_4090RTX" style="width:98%">
  </div>
 </center>
</div> 
